===========
Performance
===========

We discuss methods to improve the compuattional performance in ANDES using
Numba. Performance benchmarks are also presented.

.. toctree::

    numba
    matpower-benchmark